Crate mimxrt595_evk

Crate mimxrt595_evk 

A board support package for MIMXRT595-EVK, the official evaluation kit for the NXP i.MX RT500 family of microcontrollers.

It also includes a memory.x file intended for inclusion into the linker script provided by crate cortex-m-rt.

If you are building an application targeting this board, you will need to arrange for your flash image to contain a suitable flash control block and initial vector table so that the on-chip boot ROM will consider it eligable for use as boot media. You can get a default implementation of that by linking the separate crate mimxrt595-evk-bootstub into your program, or customize what’s generated using the macros in crate mimxrt500-bootstub.

Re-exports

pub use mimxrt500_hal as hal;

Modules

bootstub
Data for producing a flash control block describing the SPI NOR flash connected to FlexSPI0 on the evaluation kit board.
pins
Additional types used inside Pins.

Structs

Pins
Wraps the HAL-level Pins with alternative pin names that match the documented connections on the evaluation kit board.